$(function(){
	document.addEventListener('touchmove', function(e){ e.preventDefault(); }, false);
	FastClick.attach(document.body);
	
	$(".cp_player").fitVids();
	
	if(settings.debugMode === true){
		var testCourseId = "G01C01";
		loadCoursePreviewData(testCourseId);
	}
});

function closeCPPage(){
	WV.close("coursePreview", "");
}

function closeWebView(){
	closeCPPage();
}

var invoked = false;
function loadCoursePreviewData(courseId){
	if(!invoked){
		invoked = true;
		var requestUrl = "/courses/" + courseId + "/preview";
		loadData("GET", requestUrl, "", true, function(status, response){
			if(status == 200){
				initialCoursePreviewPage(response);
			}
		});
	}
}

var imageDomain = settings.courseImageDomain;
var extension = settings.courseImageExtension;

var courseId, posterUrl;
function initialCoursePreviewPage(data){
	courseId = data.CourseInfo.CourseId;
	posterUrl = data.CourseInfo.GuideVideoPosterUrl;
		
	var img = document.querySelector(".blurify");
	img.setAttribute('crossOrigin', 'anonymous');
	
	var fileName = courseId + extension;
	getItem(fileName, function(value) {
		if(value == null) {
			var ts = $.format.date(new Date(), "yyyyMMddHH");
			var imgSrc = imageDomain + fileName + "?ts=" + ts;
			
			img.setAttribute("src", imgSrc);
			img.onload = function() {
				var source = img.getAttribute("src");
				if(source != "../image/course-nothing.jpg"){
					var dataURL = getBase64Image(img, 0.5);
					lfSetItem(fileName, dataURL);
				}
			};
		} else {
			img.setAttribute("src", value);
		}
	});
	
	setTimeout(function(){
		setCourseProperty(data);
		checkPurchaseState(courseId);
		
		setTimeout(function(){
			initialPlayer(data);
			processPlayerFullScreen(cpPlayer);
		}, 100);
		
		$(".guide_panel").show();
		
		renderCourseRated(data);
		renderCPChapter(data);
		
		var defaultGroupId = groupIdArray[0];
		initialDefaultScroller(defaultGroupId);
		if(settings.platform == "ANDROID"){
			if(defaultScroller){
				defaultScroller.refresh();
			}
		}
		
		checkAndCreateScroller();
		$("#loadingPanel").hide();
		
		renderCPRatedList(courseId);
		renderCPConsult(courseId);
		loadConsultThumbsUpLog(courseId);
	}, settings.initialViewDelay);
}

function setCourseProperty(data){
	$("#guide_type").text(data.CourseInfo.GuideType == 1 ? "试学" : "导学");
	
	$("#cp_title").text(data.CourseInfo.CourseName);
	$("#cp_name").text(data.CourseInfo.CourseName);
	
	var description = data.CourseInfo.Description;
	if(!description || description == ""){
		$("#cp_desc").text("暂无课程描述");
	}else{
		$("#cp_desc").text(description);
	}
	
	$("#cp_section_count").text(data.CourseInfo.SectionCount);
	$("#cp_video_count").text(data.CourseInfo.VideoCount);
	$("#cp_purchase_count").text(data.CourseInfo.PurchaseCount);
	
	var ratedScore = data.CourseInfo.RatedScore;
	var ratedCount = data.CourseInfo.RatedCount;
	if(ratedCount > 0){
		$(".cp_rated_score").text(ratedScore);
		$("#cp_rated_count").text(ratedCount);
		$("#cp_rated_panel").show();
	}
	
	$("#salePrice").text(data.CourseInfo.Price);
	$("#cp_rated_score1").text(ratedScore);
	$("#cp_purchase_count1").text(data.CourseInfo.PurchaseCount);
}

function checkPurchaseState(courseId){
	var signState = getSignState();
	if(signState === true){
		var userId = getUserId();
		
		var requestUrl = "/courses/" + courseId + "/preview/" + userId + "/check";
		loadData("POST", requestUrl, "", false, function(status, response){
			if(status == 200){
				if(response.Purchased === true){
					var $purchaseBtn = $(".cp_purchase_btn");
					$purchaseBtn.attr("href", "javascript:;");
					$purchaseBtn.addClass("readonly");
					$purchaseBtn.text("已购买");
				}
			}
		});
	}
}

var cpPlayer;
function initialPlayer(data){
	var sourceUrl = data.CourseInfo.GuideVideoUrl;
	cpPlayer = jwplayer("cp_player").setup({
		"file": sourceUrl,
		"image": posterUrl + "?t=" + (new Date()).toString(),
		"width": "100%",
		"height": "100%",
		"aspectratio": "16:9",
		"autostart": "false"
	});
	
	bindPlayerEvents(cpPlayer);
}

var wrapperHeight;
function bindPlayerEvents(player){
	if(player){
		player.on("ready", function(e){
			var documentHeight = $(document).height();
			var videoHeight = $(".cp_guide").height();
			wrapperHeight = documentHeight - videoHeight;
			$(".cp_content").height(wrapperHeight + "px");
			
			if(settings.platform == "IOS"){
				var container = player.getContainer();
				if(container){
					container.setAttribute("playsinline", "playsinline");
					container.setAttribute("webkit-playsinline", "webkit-playsinline");
				}
			}
		});
		
		player.on('play', function(e){
			setPlayingState(player, e, true);
		});
		
		player.on('pause', function(e){
			setPlayingState(player, e, false);
		});
	}
}

function startGuide(){
	checkNetwork(startPlay, nonWIFICanPlayChoice);
}

function nonWIFICanPlayChoice(){
	weui.confirm('非WIFI网络，是否继续播放？', {
    	title: '',
    	buttons: [{
    		label: '暂不播放',
    		type: 'default',
    		onClick: function() {
    			
    		}
    	}, {
    		label: '继续播放',
    		type: 'primary',
    		onClick: function() {
    			startPlay();
    		}
    	}]
    });
}

function startPlay(){
	cpPlayer.play();
	$(".guide_panel").hide();
}

function renderCourseRated(data){
	var htmlStr = template('cpi_rated_template', data);
	$("#cp_rated_list").html(htmlStr);
	
	if(settings.platform == "ANDROID"){
		if(defaultScroller){
			defaultScroller.refresh();
		}
	}
}

function renderCPChapter(data){
	var htmlStr = template('cp_chapter_template', data);
	$("#cp_section_panel").html(htmlStr);
	
	if(settings.platform == "ANDROID"){
		if(defaultScroller){
			defaultScroller.refresh();
		}
	}
}

var groupCount = 3;
var groupIdArray = ["intro", "rated", "consult"];

var defaultScroller;
function initialDefaultScroller(defaultGroupId){
	setTimeout(function() {
		defaultScroller = new IScroll("#wrapper_" + defaultGroupId, {
			scrollbars: true,
			probeType: 3,
			mouseWheel: true,
			interactiveScrollbars: true,
			shrinkScrollbars: 'scale',
			fadeScrollbars: true
		});
		
		defaultScroller.on("scroll", togglePlayer);
		scrollerMap[defaultGroupId] = defaultScroller;
	}, 1000);
}

var scrollerTemp;
var scrollerMap = {};
function checkAndCreateScroller() {
	$('#groupPanel a').on('click', function() {
		var selectGroupId = $(this).attr("groupId");
		
		for(var i = 0; i < groupCount; i++) {
			var groupId = groupIdArray[i];
			var scroller = scrollerMap[groupId];
			
			if(!scroller){
				if(selectGroupId == groupId) {
					scrollerTemp = new IScroll("#wrapper_" + selectGroupId, {
						scrollbars: true,
						probeType: 3,
						mouseWheel: true,
						interactiveScrollbars: true,
						shrinkScrollbars: 'scale',
						fadeScrollbars: true
					});
					
					scrollerTemp.on("scroll", togglePlayer);
					scrollerMap[selectGroupId] = scrollerTemp;
				}
			}else{
				if(selectGroupId == groupId){
					scroller.refresh();
				}
			}
		}
	});
}

var hideOn = 100, showOn = 10;
var selector = "#cp_header, .cp_guide";
function togglePlayer(){
	var scrollY = -(this.y);
	
	if(this.directionY == 1) { //向上滚动
		if(scrollY >= hideOn){
			var documentHeight = $(document).height();
			$(".cp_content").height((documentHeight - 110) + "px");
			
			$(selector).hide();
		}
	} else if(this.directionY == -1) { //向下滚动
		if(scrollY < showOn){
			$(selector).show();
			
			$(".cp_content").height(wrapperHeight + "px");
		}
	}
}

function renderCPRatedList(courseId){
	var requestUrl = "/courses/" + courseId + "/rated/1/" + settings.courseRatedPageSize;
	loadData("GET", requestUrl, "", false, function(status, response){
		if(status == 200){
			var htmlStr = template('cp_rated_template', response);
			$("#course_rated_panel").html(htmlStr);
		}
	});
}

function renderCPConsult(courseId){
	var requestUrl = "/courses/" + courseId + "/consults";
	loadData("GET", requestUrl, "", false, function(status, response){
		if(status == 200){
			var data = { 'ConsultList': response };
			var htmlStr = template('cp_consult_template', data);
			$("#course_consult_panel").html(htmlStr);
		}
	});
}

function loadMoreCPRated(){	
	var requestUrl = $(".more_rated_btn").attr("url") + settings.courseRatedPageSize;
	if(requestUrl){
		loadData("GET", requestUrl, "", false, function(status, response){
			if(status == 200){
				var htmlStr = template('cp_rated_template', response);
				$("#more_rated_panel").replaceWith(htmlStr);
				
				scrollerMap["rated"].refresh();
			}
		});
	}
}

function loadConsultThumbsUpLog(courseId){
	var signState = getSignState();
	if(signState === true){
		var userId = getUserId();
		var requestUrl = "/courses/" + courseId + "/consults/" + userId + "/thumbsUp/logs";
		loadData("GET", requestUrl, "", false, function(status, response){
			if(status == 200){
				if(response && response.length > 0){
					changeConsultThumbsUpState(response);
				}
			}
		});
	}
}

function changeConsultThumbsUpState(logs){
	for (var i = 0; i < logs.length; i++) {
		var consultId = logs[i].ConsultId;
		$("#CL" + consultId).addClass("active");
		$("#CL" + consultId + " a").attr("href", "javascript:;");
	}
}

function consultThumbsUp(consultId){
	var signState = getSignState();
	if(signState === true){
		var userId = getUserId();
		var requestUrl = "/courses/" + courseId + "/consults/" + userId + "/thumbsUp/" + consultId;
		loadData("POST", requestUrl, "", false, function(status, response){
			if(status == 200 && response == true){
				$("#CL" + consultId).addClass("active");
				
				var $thumbsUpCount = $("#CL" + consultId + " span");
				var count = $thumbsUpCount.text();
				$thumbsUpCount.text(Number(count) + 1);
				
				$("#CL" + consultId + " a").attr("href", "javascript:;");
			}
		});
	}else{
		showToast("登录后才能点赞哦", 1000);
	}
}

function showConsultSlidePanel(){
	var signState = getSignState();
	if(signState === true){
		$("#sp_consult_panel").animate({left: '0'});
		$("#menu").attr("data-mfb-state", "closed");
		setHasSP(true);
	}else{
		showToast("登录后才能咨询哦", 1000);
		$("#menu").attr("data-mfb-state", "closed");
	}
}

function submitConsultQuestion(){
	var signState = getSignState();
	if(signState === true){
		var userId = getUserId();
		var $question = $("#question");
		var questionComment = $question.val().trim();
		if(!questionComment || questionComment == ""){
			$("#question_error").text("请描述您要咨询的问题");
			$question.parent().addClass("is-invalid");
		}else{
			var requestUrl = "/courses/" + courseId + "/consults/" + userId + "/question";
			loadData("POST", requestUrl, { "comment": questionComment }, false, function(status, response){
				if(status == 200){
					if(response && response === true){
						$question.val("");
						document.querySelector("#mdl_tf_question").MaterialTextfield.checkDirty();
						
						hideSlidePanel();
						setTimeout(function(){
							showToast("提交成功", 1000);
						}, 400);
					}
				}
			});
		}
	}
}

function hideConsultSlidePanel(){
	setHasSP(false);
	$("#sp_consult_panel").animate({left: '100%'});
}

function hideSlidePanel(){
	hideConsultSlidePanel();
}

function gotoRatedTab(){
	$(".mdl-tabs__tab:eq(1) span").click();
	$(".tab_panels").scrollTop(1);
}

function openPurchasePage(){
	var signState = getSignState();
	if(signState === true){
		var wvName = "purchase";
		var wvCP = WV.load(wvName);
		var viewObj = window[wvName];
		
		if(settings.platform == "IOS"){
			wvCP.addEventListener("loaded", function(e){
				wvCP.evalJS("loadPurchasePage(1, '" + courseId + "')");
				
				setTimeout(function(){
					var animation = viewObj.ShowAnimation;
					wvCP.show(animation, WV.AnimationDuration, function() {
						WV.showedCB(wvName, "");
					});
				}, settings.openWebviewDelay);
			}, false);
		}else{
			wvCP.evalJS("loadPurchasePage(1, '" + courseId + "')");
		
			wvCP.addEventListener("titleUpdate", function(e){
				setTimeout(function(){
					var animation = viewObj.ShowAnimation;
					wvCP.show(animation, WV.AnimationDuration, function() {
						WV.showedCB(wvName, "");
					});
				}, settings.openWebviewDelay);
			}, false);
		}
	}else{
		showToast("登录后才能购买哦", 1000);
	}
}
