$(function(){
	if(settings.debugMode === true){
		var testClassId = "S01C01";
		loadClassPreviewData(testClassId);
	}
	
	scrollToggleVideo(".tab_panels", "#cp_header, .cp_guide");
});

var cpPlayer;
function initialPlayer(data){
	var sourceUrl = data.ServiceInfo.GuideVideoUrl;
	cpPlayer = jwplayer("cp_player").setup({
		"file": sourceUrl,
		"image": posterUrl + "?t=" + (new Date()).toString(),
		"width": "100%",
		"aspectratio": "16:9",
		"autostart": "false"
	});
	
	bindPlayerEvents(cpPlayer);
}

function bindPlayerEvents(player){
	if(player){
		player.on('play', function(e){
			setPlayingState(player, e, true);
		});
		
		player.on('pause', function(e){
			setPlayingState(player, e, false);
		});
	}
}

var serviceClassId;
function loadClassPreviewData(classId){
	serviceClassId = classId;
	var queryString = "classId=" + classId;
	var requestUrl = "/classes/" + classId + "/preview";
	loadData("GET", requestUrl, queryString, false, function(status, response){
		if(status == 200){
			initialClassPreviewPage(response);
		}
	});
}

function closeCPPage(){
	WV.close('classPreview', '');
}

function closeWebView(){
	closeCPPage();
}

var serviceId, posterUrl;
function initialClassPreviewPage(data){
	serviceId = data.ServiceInfo.ServiceId;
	posterUrl = data.ServiceInfo.GuideVideoPosterUrl;
	
	$(".cp_guide").fitVids();
	if(posterUrl){
		var t = $.format.date(new Date(), "yyyyMMddHH");
		$(".blurify").attr("data-src", posterUrl + "?t=" + t);
		
		new blurify({
		    images: document.querySelectorAll('.blurify'),
		    blur: settings.imageBlurValue,
		    mode: 'canvas',
		});
	}
	
	setTimeout(function(){
		setClassProperty(data);
		
		initialPlayer(data);
		processPlayerFullScreen(cpPlayer);
		$(".guide_panel").show();
		
		checkPurchaseState(serviceClassId);
		$("#loadingPanel").hide();
		
		renderServiceRated(data);
		renderCPCourseChapter(data);
		
		renderCPRatedList(serviceId);
		renderCPConsult(serviceId);
		loadConsultThumbsUpLog(serviceId);
	}, settings.initialViewDelay);
}

function startGuide(){
	checkNetwork(startPlay, nonWIFICanPlayChoice);
}

function startPlay(){
	cpPlayer.play();
	$(".guide_panel").hide();
}

function nonWIFICanPlayChoice(){
	weui.confirm('非WIFI网络，是否继续播放？', {
    	title: '',
    	buttons: [{
    		label: '暂不播放',
    		type: 'default',
    		onClick: function() {
    			
    		}
    	}, {
    		label: '继续播放',
    		type: 'primary',
    		onClick: function() {
    			startPlay();
    		}
    	}]
    });
}

function setClassProperty(data){
	$("#guide_type").text(data.ServiceInfo.GuideType == 1 ? "试学" : "导学");
	
	var serviceName = data.ServiceInfo.ServiceName;
	var periodName = data.ServiceClass.PeriodName;
	$("#cp_title").text(serviceName);
	$("#cp_name").text(serviceName + " - " + periodName);
	
	var introduce = data.ServiceClass.Introduce;
	if(!introduce || introduce == ""){
		$("#cp_desc").text("暂无班级描述");
	}else{
		$("#cp_desc").text(data.ServiceClass.Introduce);
	}
	
	var courseVideoCount = data.ServiceClass.TapedCourseVideoCount;
	var liveLessonCount = data.ServiceClass.LiveLessonCount;
	$("#cp_total_count").text(courseVideoCount + liveLessonCount);
	
	var enteredCount = data.ServiceClass.EnteredCount;
	var recruitCount = data.ServiceClass.RecruitCount;
	var shengYu = recruitCount - enteredCount;
	$("#cp_recruit_count").text(shengYu + "/" + recruitCount);
	$("#cp_opening_date").text($.format.date(data.ServiceClass.OpeningDate, "MM-dd"));
	$("#cp_shengyu_count").text(shengYu + "个");
	
	var ratedCount = data.ServiceInfo.RatedCount;
	if(ratedCount > 0){
		$(".cp_rated_score").text(data.ServiceInfo.RatedScore);
		$("#cp_rated_count").text(ratedCount);
		$("#cp_rated_panel").show();
	}
	
	$("#salePrice").text(data.ServiceClass.Price);
	
	var ssd = $.format.date(data.ServiceClass.StopSaleDate, "yyyy-MM-dd HH:mm:ss");
	var diff = new DateDiff(new Date(ssd), new Date());
	var stopSaleDays = parseInt(diff.days());
	if(stopSaleDays > 0){
		$("#stopSaleDays").text(stopSaleDays + "天");
	}else{
		var stopSaleHours = parseInt(diff.hours());
		if(stopSaleHours > 0){
			$("#stopSaleDays").text(stopSaleHours + "小时");
		}else{
			var stopSaleMinutes = parseInt(diff.minutes());
			if(stopSaleMinutes > 0){
				$("#stopSaleDays").text(stopSaleMinutes + "分钟");
			}else{
				$("#stopSaleDays").text("NaN");
				var $purchaseBtn = $(".cp_purchase_btn");
				$purchaseBtn.attr("href", "javascript:;");
				$purchaseBtn.addClass("readonly");
				$purchaseBtn.text("已停售");
			}
		}
	}
}

function checkPurchaseState(classId){
	var signState = getSignState();
	if(signState === true){
		var userId = getUserId();
		
		var requestUrl = "/classes/" + classId + "/preview/" + userId + "/check";
		loadData("POST", requestUrl, "", false, function(status, response){
			if(status == 200){
				if(response.Purchased === true){
					var $purchaseBtn = $(".cp_purchase_btn");
					$purchaseBtn.attr("href", "javascript:;");
					$purchaseBtn.addClass("readonly");
					$purchaseBtn.text("已报名");
				}
			}
		});
	}
}

function renderServiceRated(data){
	var htmlStr = template('cpi_rated_template', data);
	$("#cp_rated_list").html(htmlStr);
}

function renderCPCourseChapter(data){
	var htmlStr = template('cp_chapter_template', data);
	$("#cp_section_panel").html(htmlStr);
}

function renderCPRatedList(serviceId){
	var requestUrl = "/services/" + serviceId + "/rated/1/" + settings.courseRatedPageSize;
	loadData("GET", requestUrl, "", false, function(status, response){
		if(status == 200){
			var htmlStr = template('cp_rated_template', response);
			$("#class_rated_panel").html(htmlStr);
		}
	});
}

function loadMoreCPRated(){	
	var requestUrl = $(".more_rated_btn").attr("url") + settings.courseRatedPageSize;
	if(requestUrl){
		loadData("GET", requestUrl, "", false, function(status, response){
			if(status == 200){
				var htmlStr = template('cp_rated_template', response);
				$("#more_rated_panel").replaceWith(htmlStr);
			}
		});
	}
}

function renderCPConsult(serviceId){
	var requestUrl = "/services/" + serviceId + "/consults";
	loadData("GET", requestUrl, "", false, function(status, response){
		if(status == 200){
			var data = { 'ConsultList': response };
			
			var htmlStr = template('cp_consult_template', data);
			$("#service_consult_panel").html(htmlStr);
		}
	});
}

function submitConsultQuestion(){
	if(getSignState() === true){
		var userId = getUserId();
		var $question = $("#question");
		var questionComment = $question.val().trim();
		if(!questionComment || questionComment == ""){
			$("#question_error").text("请描述您要咨询的问题");
			$question.parent().addClass("is-invalid");
		}else{
			var requestUrl = "/services/" + serviceId + "/consults/" + userId + "/question";
			loadData("POST", requestUrl, { "comment": questionComment }, false, function(status, response){
				if(status == 200){
					if(response && response === true){
						$question.val("");
						document.querySelector("#mdl_tf_question").MaterialTextfield.checkDirty();
						
						hideSlidePanel();
						setTimeout(function(){
							showToast("提交成功", 1000);
						}, 400);
					}
				}
			});
		}
	}
}

function loadConsultThumbsUpLog(serviceId){
	var signState = getSignState();
	if(signState === true){
		var userId = getUserId();
		var requestUrl = "/services/" + serviceId + "/consults/" + userId + "/thumbsUp/logs";
		loadData("GET", requestUrl, "", false, function(status, response){
			if(status == 200){
				if(response && response.length > 0){
					changeConsultThumbsUpState(response);
				}
			}
		});
	}
}

function changeConsultThumbsUpState(logs){
	for (var i = 0; i < logs.length; i++) {
		var consultId = logs[i].ConsultId;
		$("#CL" + consultId).addClass("active");
		$("#CL" + consultId + " a").attr("href", "javascript:;");
	}
}

function consultThumbsUp(consultId){
	var signState = getSignState();
	if(signState === true){
		var userId = getUserId();
		var requestUrl = "/services/" + serviceId + "/consults/" + userId + "/thumbsUp/" + consultId;
		loadData("POST", requestUrl, { "userId": userId }, false, function(status, response){
			if(status == 200 && response === true){
				$("#CL" + consultId).addClass("active");
				
				var $thumbsUpCount = $("#CL" + consultId + " span");
				var count = $thumbsUpCount.text();
				$thumbsUpCount.text(Number(count) + 1);
				
				$("#CL" + consultId + " a").attr("href", "javascript:;");
			}
		});
	}
}

function showConsultSlidePanel(){
	var signState = getSignState();
	if(signState === true){
		$("#sp_consult_panel").animate({left: '0'});
		$("#menu").attr("data-mfb-state", "closed");
		setHasSP(true);
	}else{
		showToast("登录后才能咨询哦", 1000);
		$("#menu").attr("data-mfb-state", "closed");
	}
}

function hideConsultSlidePanel(){
	$("#sp_consult_panel").animate({left: '100%'});
	setHasSP(false);
}

function hideSlidePanel(){
	hideConsultSlidePanel();
}

function gotoRatedTab(){
	$(".mdl-tabs__tab:eq(1) span").click();
	$(".tab_panels").scrollTop(1);
}

function openPurchasePage(){
	var wvCP = WV.load("purchase");
	wvCP.evalJS("loadPurchasePage(2, '" + serviceClassId + "')");
	
	var viewObj = window["purchase"];
	
	wvCP.addEventListener("titleUpdate", function(e){
		setTimeout(function(){
			var animation = viewObj.ShowAnimation;
			wvCP.show(animation, WV.AnimationDuration, function() {
				WV.showedCB("purchase", "");
			});
		}, settings.openWebviewDelay);
	}, false);
}
